==> atmos-2.98.1.tar.gz: atmos-2.98.1/src/integrals.h <==
/*
    $Id: integrals.h 166 2010-10-29 15:22:58Z matwey $
    Copyright (C) 2009  Sternberg Astronomical Institute, MSU

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _INTEGRALS_H
#define _INTEGRALS_H

#include <string>
#include <stdexcept>

#include <boost/tuple/tuple.hpp>
#include <boost/numeric/ublas/matrix.hpp>
#include <boost/numeric/ublas/vector.hpp>

#include "table_storage.h"
#include "nocase_less.h"

#include "utils.h"
#include "indices.h"

namespace atmos {
namespace integrals {
	using namespace boost::numeric::ublas;
	
	typedef double value_type;
	typedef matrix< value_type > matrix_type;

namespace detail {
	struct sample {
		typedef atmos::integrals::value_type value_type;

		value_type free_seeing;
		value_type isoplanatic_angle;
		value_type altitude_eff;
		value_type time_constant;
		value_type moment_0;
		value_type moment_2;

		sample( const value_type& free_seeing,
			const value_type& isoplanatic_angle,
			const value_type& altitude_eff,
			const value_type& time_constant,
			const value_type& moment_0,
			const value_type& moment_2 ):
			free_seeing(free_seeing), isoplanatic_angle(isoplanatic_angle), altitude_eff(altitude_eff), time_constant(time_constant), moment_0(moment_0), moment_2(moment_2) {
		}
	};
}

class storage:
	public table_storage< detail::sample > {
public:
	typedef table_storage_column< detail::sample, boost::function1< detail::sample::value_type, detail::sample > > common_column_type;
	typedef common_column_type free_seeing_column_type;
	typedef common_column_type isoplanatic_angle_column_type;
	typedef common_column_type altitude_eff_column_type;
	typedef common_column_type time_constant_column_type;
	typedef common_column_type moment_0_column_type;
	typedef common_column_type moment_2_column_type;
private:
	free_seeing_column_type       m_free_seeing_column;
	isoplanatic_angle_column_type m_isoplanatic_angle_column;
	altitude_eff_column_type      m_altitude_eff_column;
	time_constant_column_type     m_time_constant_column;
	moment_0_column_type          m_moment_0_column;
	moment_2_column_type          m_moment_2_column;
public:
	storage( size_type reserve = 60 );

	const free_seeing_column_type&       free_seeing()       const { return m_free_seeing_column; }
	const isoplanatic_angle_column_type& isoplanatic_angle() const { return m_isoplanatic_angle_column; }
	const altitude_eff_column_type&      altitude_eff()      const { return m_altitude_eff_column; }
	const time_constant_column_type&     time_constant()     const { return m_time_constant_column; }
	const moment_0_column_type&          moment_0()          const { return m_moment_0_column; }
	const moment_2_column_type&          moment_2()          const { return m_moment_2_column; }

	void push_back( const detail::sample& integrals ) {
		table_storage< detail::sample >::push_back( integrals );
	}
};

namespace filter {
	class regular {
	public:
		typedef atmos::integrals::detail::sample sample_type;
	public:
		bool operator() ( const sample_type& x ) const;
	private:
		bool is_regular( double x ) const;
	};
}

class functor_factory;
class functor;

class functor_factory {
	public:
		typedef matrix_type dcf_matrix_type;
		typedef boost::function1< vector<double>, double > weight_type;
		typedef std::map< std::string, dcf_matrix_type, utils::algo::nocase_less< std::string > > storage_type;
		typedef functor functor_type;
	private:
		storage_type m_storage;

		dcf_matrix_type calculate( const std::string& spectral_type, const weight_type& awf );
	public:
		functor_factory();
		functor_factory( const functor_factory& factory );
		void swap( functor_factory& factory ) throw();
		functor_factory& operator=( const functor_factory& factory );
		~functor_factory();

		functor_type operator() ( const std::string& spectral_type, const weight_type& awf );
};

class functor {
	public:
		typedef matrix_type dcf_matrix_type;

		typedef atmos::indices::indices_type indices_type;
		typedef atmos::indices::indesis_type indesis_type;
		typedef atmos::integrals::detail::sample result_type;
	private:
		const dcf_matrix_type& m_dcf;
	public:
		functor( const dcf_matrix_type& dcf ):
			m_dcf( dcf ) {}

		result_type operator() ( const indices_type& indices, const indesis_type& indesis, double mz ) const;
};

}}

#endif // _INTEGRALS_H

==> atmos-2.98.7.tar.gz: atmos-2.98.7/src/integrals.h <==
/*
    $Id: integrals.h 196 2011-02-02 09:42:14Z matwey $
    Copyright (C) 2009  Sternberg Astronomical Institute, MSU

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _INTEGRALS_H
#define _INTEGRALS_H

#include <string>
#include <stdexcept>

#include <boost/tuple/tuple.hpp>
#include <boost/numeric/ublas/matrix.hpp>
#include <boost/numeric/ublas/vector.hpp>

#include "table_storage.h"
#include "nocase_less.h"

#include "utils.h"
#include "indices.h"

namespace atmos {
namespace integrals {
	using namespace boost::numeric::ublas;
	
	typedef double value_type;
	typedef vector< value_type > vector_type;
	typedef matrix< value_type > matrix_type;

namespace detail {
	struct sample {
		typedef atmos::integrals::value_type value_type;

		value_type free_seeing;
		value_type isoplanatic_angle;
		value_type altitude_eff;
		value_type time_constant;
		value_type desi_time_constant;
		value_type moment_0;
		value_type moment_2;

		sample( const value_type& free_seeing,
			const value_type& isoplanatic_angle,
			const value_type& altitude_eff,
			const value_type& desi_time_constant,
			const value_type& time_constant,
			const value_type& moment_0,
			const value_type& moment_2 ):
			free_seeing(free_seeing), isoplanatic_angle(isoplanatic_angle), altitude_eff(altitude_eff), desi_time_constant(desi_time_constant), time_constant(time_constant), moment_0(moment_0), moment_2(moment_2) {
		}
	};
}

class storage:
	public table_storage< detail::sample > {
public:
	typedef table_storage_column< detail::sample, boost::function1< detail::sample::value_type, detail::sample > > common_column_type;
	typedef common_column_type free_seeing_column_type;
	typedef common_column_type isoplanatic_angle_column_type;
	typedef common_column_type altitude_eff_column_type;
	typedef common_column_type time_constant_column_type;
	typedef common_column_type desi_time_constant_column_type;
	typedef common_column_type moment_0_column_type;
	typedef common_column_type moment_2_column_type;
private:
	free_seeing_column_type       m_free_seeing_column;
	isoplanatic_angle_column_type m_isoplanatic_angle_column;
	altitude_eff_column_type      m_altitude_eff_column;
	time_constant_column_type     m_time_constant_column;
	desi_time_constant_column_type m_desi_time_constant_column;
	moment_0_column_type          m_moment_0_column;
	moment_2_column_type          m_moment_2_column;
public:
	storage( size_type reserve = 60 );

	const free_seeing_column_type&       free_seeing()       const { return m_free_seeing_column; }
	const isoplanatic_angle_column_type& isoplanatic_angle() const { return m_isoplanatic_angle_column; }
	const altitude_eff_column_type&      altitude_eff()      const { return m_altitude_eff_column; }
	const desi_time_constant_column_type& desi_time_constant() const { return m_desi_time_constant_column; }
	const time_constant_column_type&     time_constant()     const { return m_time_constant_column; }
	const moment_0_column_type&          moment_0()          const { return m_moment_0_column; }
	const moment_2_column_type&          moment_2()          const { return m_moment_2_column; }

	void push_back( const detail::sample& integrals ) {
		table_storage< detail::sample >::push_back( integrals );
	}
};

namespace filter {
	class regular {
	public:
		typedef atmos::integrals::detail::sample sample_type;
	public:
		bool operator() ( const sample_type& x ) const;
	private:
		bool is_regular( double x ) const;
	};
}

class functor_factory;
class functor;

class functor_factory {
	public:
		typedef matrix_type dcf_matrix_type;
		typedef boost::function1< vector<double>, double > weight_type;
		typedef functor functor_type;
		typedef std::map< std::string, functor_type, utils::algo::nocase_less< std::string > > storage_type;
	private:
		storage_type m_storage;

		dcf_matrix_type calculate( const weight_type& wf, unsigned int npower, const double* powers );
	public:
		functor_factory();
		functor_factory( const functor_factory& factory );
		void swap( functor_factory& factory ) throw();
		functor_factory& operator=( const functor_factory& factory );
		~functor_factory();

		const functor_type& operator() ( const std::string& spectral_type, const weight_type& null_wf, const weight_type& second_wf );
};

class functor {
	public:
		typedef matrix_type dcf_matrix_type;

		typedef atmos::indices::indices_type indices_type;
		typedef atmos::indices::indesis_type indesis_type;
		typedef atmos::integrals::detail::sample result_type;
	private:
		dcf_matrix_type m_indices_dcf;
		dcf_matrix_type m_wind_indices_dcf;
	public:
		functor( const dcf_matrix_type& indices_dcf, const dcf_matrix_type& wind_indices_dcf ):
			m_indices_dcf( indices_dcf ), m_wind_indices_dcf( wind_indices_dcf ) {}

		result_type operator() ( const indices_type& indices, const indesis_type& indesis, const indices_type& wind_indices, double mz ) const;
};

}}

#endif // _INTEGRALS_H
